
<?php

// =============================================================================
// CORNERSTONE/INCLUDES/ELEMENTS/DEFINITIONS/CONTENT-AREA-DROPDOWN.PHP
// -----------------------------------------------------------------------------
// V2 element definitions.
// =============================================================================

// =============================================================================
// TABLE OF CONTENTS
// -----------------------------------------------------------------------------
//   01. Values
//   02. Style
//   03. Render
//   04. Builder Setup
//   05. Register Element
// =============================================================================

// Values
// =============================================================================

$values = cs_compose_values(
  'toggle',
  'toggle:custom-atts',
  'dropdown',
  'dropdown:custom-atts',
  'omega',
  'omega:toggle-hash',
  'omega:looper-consumer'
);



// Style
// =============================================================================

function x_element_style_layout_dropdown() {
  $style = cs_get_partial_style( 'anchor', array(
    'selector'   => '',
    'key_prefix' => 'toggle'
  ) );

  $style .= cs_get_partial_style( 'dropdown' );

  $style .= cs_get_partial_style( 'effects', array(
    'selector' => '.x-anchor',
    'children' => ['.x-anchor-text-primary', '.x-anchor-text-secondary', '.x-graphic-child'],
  ) );

  return $style;
}



// Render
// =============================================================================

function x_element_render_layout_dropdown( $data ) {
  
  $data = array_merge(
    $data,
    cs_make_aria_atts( 'toggle_anchor', array(
      'controls' => 'dropdown',
      'haspopup' => 'true',
      'expanded' => 'false',
      'label'    => __( 'Toggle Dropdown Content', '__x__' ),
    ), $data['id'], $data['unique_id'] )
  );

  // Prepare Atts
  // ------------

  $atts = array(
    'class' => x_attr_class( array( $data['style_id'], 'x-mod-container', $data['class'] ) )
  );

  if ( isset( $data['id'] ) && ! empty( $data['id'] ) ) {
    $atts['id'] = $data['id'];
  }


  // Data: Partials
  // --------------

  $data_toggle   = cs_extract( $data, array( 'toggle_anchor' => 'anchor', 'toggle' => '', 'effects' => '' ) );
  
  ob_start();
  do_action( 'x_layout_dropdown', $data['_modules'], $data );
  $dropdown_content = ob_get_clean();

  $data_dropdown = array_merge( cs_extract( $data, array( 'dropdown' => '' ) ), [ 'dropdown_content' => $dropdown_content ]);

  // Output
  // ------

  return x_tag('div', $atts, [
    cs_get_partial_view( 'anchor', $data_toggle ),
    cs_get_partial_view( 'dropdown', $data_dropdown )
  ]);

}



// Builder Setup
// =============================================================================

function x_element_builder_setup_layout_dropdown() {
  return cs_compose_controls(
    [
      'controls' => [
        [
          'type'  => 'sortable',
          'label' => __( 'Children', '__x__' ),
          'group' => 'dropdown:setup'
        ]
      ]
    ],
    cs_partial_controls( 'dropdown', array( 'add_custom_atts' => true ) ),
    cs_partial_controls( 'anchor', cs_recall( 'settings_anchor:toggle' ) ),
    cs_partial_controls( 'effects' ),
    cs_partial_controls( 'omega', array( 'add_toggle_hash' => true, 'add_looper_consumer' => true ) )
  );
}



// Register Element
// =============================================================================

cs_register_element( 'layout-dropdown', [
  'title'   => __( 'Dropdown', '__x__' ),
  'values'  => $values,
  'components' => [ 'effects' ],
  'builder' => 'x_element_builder_setup_layout_dropdown',
  'style'   => 'x_element_style_layout_dropdown',
  'render'  => 'x_element_render_layout_dropdown',
  'icon'    => 'native',
  'children' => 'x_layout_dropdown',
  'options' => [
    'valid_children'    => [ '*' ],
    'index_labels'      => false,
    'library'           => true,
    'dropzone'          => [
      'enabled' => true
    ],
    'toggle_on_create' => [
      'enabled' => true
    ]
  ]
] );
