<?php

// =============================================================================
// CORNERSTONE/INCLUDES/ELEMENTS/DEFINITIONS/CONTENT-AREA-MODAL.PHP
// -----------------------------------------------------------------------------
// V2 element definitions.
// =============================================================================

// =============================================================================
// TABLE OF CONTENTS
// -----------------------------------------------------------------------------
//   01. Values
//   02. Style
//   03. Render
//   04. Builder Setup
//   05. Register Element
// =============================================================================

// Values
// =============================================================================

$values = cs_compose_values(
  'toggle',
  'toggle:custom-atts',
  'modal',
  'omega',
  'omega:toggle-hash',
  'omega:looper-consumer'
);



// Style
// =============================================================================

function x_element_style_layout_modal() {
  $style = cs_get_partial_style( 'anchor', array(
    'selector'   => '',
    'key_prefix' => 'toggle'
  ) );

  $style .= cs_get_partial_style( 'effects', array(
    'selector' => '.x-anchor',
    'children' => ['.x-anchor-text-primary', '.x-anchor-text-secondary', '.x-graphic-child'],
  ) );

  $style .= cs_get_partial_style( 'modal' );

  return $style;
}



// Render
// =============================================================================

function x_element_render_layout_modal( $data ) {
  $data = array_merge(
    $data,
    cs_make_aria_atts( 'toggle_anchor', array(
      'controls' => 'modal',
      'haspopup' => 'true',
      'expanded' => 'false',
      'label'    => __( 'Toggle Modal Content', '__x__' ),
    ), $data['id'], $data['unique_id'] )
  );

  $modal_data = cs_extract( $data, array( 'modal' => '' ) );

  ob_start();
  do_action( 'x_layout_modal', $data['_modules'], $data );

  $modal_data['modal_content'] = x_tag('div', ['data-dropzone'], [
    "TEST", "TEST2",
    ob_get_clean()
  ]);
  
  cs_defer_partial( 'x_before_site_end', 'modal', $modal_data );

  return cs_get_partial_view( 'anchor', cs_extract( $data, array( 'toggle_anchor' => 'anchor', 'toggle' => '', 'effects' => '' ) ) );
}



// Builder Setup
// =============================================================================

function x_element_builder_setup_layout_modal() {
  
  return cs_compose_controls(
    [
      'controls' => [
        [
          'type'  => 'sortable',
          'label' => __( 'Children', '__x__' ),
          'group' => 'modal:setup'
        ]
      ]
    ],
    cs_partial_controls( 'modal' ),
    cs_partial_controls( 'anchor', cs_recall( 'settings_anchor:toggle' ) ),
    cs_partial_controls( 'effects' ),
    cs_partial_controls( 'omega', array( 'add_toggle_hash' => true, 'add_looper_consumer' => true ) )
  );
}


// Register Element
// =============================================================================

cs_register_element( 'layout-modal', [
  'title'   => __( 'Modal', '__x__' ),
  'values'  => $values,
  'components' => [ 'effects' ],
  'builder' => 'x_element_builder_setup_layout_modal',
  'style'   => 'x_element_style_layout_modal',
  'render'  => 'x_element_render_layout_modal',
  'icon'    => 'native',
  'children' => 'x_layout_modal',
  'options' => [
    'valid_children'    => [ '*' ],
    'index_labels'      => false,
    'library'           => true,
    // 'dropzone'          => [
    //   'enabled' => true
    // ],
    'toggle_on_create' => [
      'enabled' => true
    ]
  ]
] );
